==> org-lsst-ccs-subsystem-fcs-buses-5.5.12-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByEPOSController.java <==

package org.lsst.ccs.subsystems.fcs;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposState;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposMode;
/**
 *
 * @author virieux
 */
public class StatusDataPublishedByEPOSController extends StatusDataPublishedByCanOpenDevice {
    private static final long serialVersionUID = 3257626294501878990L;

    private EposMode mode;
    private boolean controllerWithBrake = false;
    private boolean brakeActivated;
    private EposState state;
    
    @DataAttributes(description = "actual current read on controller : index 0x6078", units = "mA")
    private int current;
    
    private int position;
    
    @DataAttributes(description = "velocity read on controller : index 0x2028 subindex 0", units = "rpm")
    private int velocity;

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized, boolean inError, String errorRegister, int errorHistoryNB, int lastErrorCode, String lastErrorName) {
        super(isBooted, isInitialized, inError, errorRegister, errorHistoryNB, lastErrorCode, lastErrorName);
    }

    public EposMode getMode() {
        return mode;
    }

    public void setMode(EposMode mode) {
        this.mode = mode;
    }

    public boolean isControllerWithBrake() {
        return controllerWithBrake;
    }

    public void setControllerWithBrake(boolean controllerWithBrake) {
        this.controllerWithBrake = controllerWithBrake;
    }

    public boolean isBrakeActivated() {
        return brakeActivated;
    }

    public void setBrakeActivated(boolean brakeActivated) {
        this.brakeActivated = brakeActivated;
    }

    public EposState getState() {
        return state;
    }

    public void setState(EposState state) {
        this.state = state;
    }

    public int getCurrent() {
        return current;
    }

    public void setCurrent(int current) {
        this.current = current;
    }

    public int getPosition() {
        return position;
    }

    public void setPosition(int position) {
        this.position = position;
    }

    public int getVelocity() {
        return velocity;
    }

    public void setVelocity(int velocity) {
        this.velocity = velocity;
    }
}

==> org-lsst-ccs-subsystem-fcs-buses-6.1.0-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByEPOSController.java <==

package org.lsst.ccs.subsystems.fcs;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposState;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposMode;
/**
 *
 * @author virieux
 */
public class StatusDataPublishedByEPOSController extends StatusDataPublishedByCanOpenDevice {
    private static final long serialVersionUID = 3257626294501878990L;

    private EposMode mode;
    private boolean controllerWithBrake = false;
    private boolean brakeActivated;
    private EposState state;
    
    @DataAttributes(description = "actual current read on controller : index 0x6078", units = "mA")
    private int current;

    @DataAttributes(description = "position read on controller : index:0x6064 subindex:0", units = "mA")
    private int position;
    
    @DataAttributes(description = "velocity read on controller : index 0x2028 subindex 0 [rpm]" , units = "unitless")
    private int velocity;

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized, boolean inError, String errorRegister, int errorHistoryNB, int lastErrorCode, String lastErrorName) {
        super(isBooted, isInitialized, inError, errorRegister, errorHistoryNB, lastErrorCode, lastErrorName);
    }

    public EposMode getMode() {
        return mode;
    }

    public void setMode(EposMode mode) {
        this.mode = mode;
    }

    public boolean isControllerWithBrake() {
        return controllerWithBrake;
    }

    public void setControllerWithBrake(boolean controllerWithBrake) {
        this.controllerWithBrake = controllerWithBrake;
    }

    public boolean isBrakeActivated() {
        return brakeActivated;
    }

    public void setBrakeActivated(boolean brakeActivated) {
        this.brakeActivated = brakeActivated;
    }

    public EposState getState() {
        return state;
    }

    public void setState(EposState state) {
        this.state = state;
    }

    public int getCurrent() {
        return current;
    }

    public void setCurrent(int current) {
        this.current = current;
    }

    public int getPosition() {
        return position;
    }

    public void setPosition(int position) {
        this.position = position;
    }

    public int getVelocity() {
        return velocity;
    }

    public void setVelocity(int velocity) {
        this.velocity = velocity;
    }
}
